Documentation
¶
Overview ¶
Package format implements formatting of Rego source files.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Ast ¶
Ast formats a Rego AST element. If the passed value is not a valid AST element, Ast returns nil and an error. If AST nodes are missing locations an arbitrary location will be used.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.